@@ -1,6 +1,6 @@
-//$Id: button-prop.cc,v 1.23 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.25 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -26,7 +26,6 @@
 #include "widgets/propertytable.h"
 #include <gtk--/menu.h>
 
-#include "widget-prop.h"
 #include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
@@ -36,6 +35,7 @@ using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
 ButtonProperties::ButtonProperties (Button *res_):
+    WidgetProperties (res_),
     res (res_),
     update_block (false)
 {
@@ -46,7 +46,7 @@ ButtonProperties::ButtonProperties (Button *res_):
     Gtk::Widget *control;
 
     /* Resource ID */
-    WidgetProperties::add_general_controls (res, *proptable);
+    add_general_controls (*proptable);
 
     /* Label */
     TextualProperties::add_controls (res, *proptable);
@@ -100,7 +100,7 @@ ButtonProperties::ButtonProperties (Button *res_):
     proptable->add_separator ();
 
     /* Position */
-    WidgetProperties::add_position_controls (res, *proptable);
+    add_position_controls (*proptable);
     
     /* Size */
     AutoWidthProperties::add_controls  (res, *proptable);
