@@ -1,6 +1,6 @@
-//$Id: checkbox.cc,v 1.24 2002/06/14 21:37:53 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.27 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -25,13 +25,13 @@ using Guikachu::Widgets::Checkbox;
 using namespace Guikachu::GUI::FormEditor;
 
 Checkbox::Checkbox (Resources::Form   *owner,
-		    const std::string &id):
-    Widget (owner, id),
+		    const std::string &id,
+		    serial_t           serial):
+    Widget (owner, id, serial),
     ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
-    editor (0),
     usable (changed, true),
     anchor_right (changed, false),
     group (this),
@@ -39,12 +39,6 @@ Checkbox::Checkbox (Resources::Form   *owner,
 {
 }
 
-Checkbox::~Checkbox ()
-{
-    if (editor)
-	delete editor;
-}
-
 Checkbox::GroupProp::GroupProp (Checkbox *owner_):
     Property<int> (owner_->changed),
     owner (owner_)
@@ -117,19 +111,6 @@ void Checkbox::GroupProp::set_val (const int& value_)
     changed ();
 }
 
-Gtk::Widget *Checkbox::create_editor ()
-{
-    if (!editor)
-	editor = new CheckboxProperties (this);
-    
-    return editor->get_editor ();
-}
-
-WidgetCanvasItem* Checkbox::create_canvas_item (Gnome::CanvasGroup *parent_group)
-{
-    return new CheckboxCanvasItem (this, parent_group);
-}
-
 int Checkbox::get_auto_width () const
 {
     return 18 + get_line_width (font, text);
