@@ -1,6 +1,6 @@
-//$Id: popup-trigger.cc,v 1.23 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.26 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,6 @@
  */
 
 #include "popup-trigger.h"
-#include "popup-trigger-canvas.h"
 
 #include "form-editor.h"
 
@@ -25,39 +24,20 @@ using Guikachu::Widgets::PopupTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
 PopupTrigger::PopupTrigger (Resources::Form   *owner,
-			    const std::string &id):
-    Widget (owner, id),
+			    const std::string &id,
+			    serial_t           serial):
+    Widget (owner, id, serial),
     ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
-    
-    editor (0),
+
     list_id (changed, owner),
     usable (changed, true),
     anchor_right (changed, false)
 {
 }
 
-PopupTrigger::~PopupTrigger ()
-{
-    if (editor)
-	delete editor;
-}
-
-Gtk::Widget *PopupTrigger::create_editor ()
-{
-    if (!editor)
-	editor = new PopupTriggerProperties (this);
-    
-    return editor->get_editor ();
-}
-
-WidgetCanvasItem* PopupTrigger::create_canvas_item (Gnome::CanvasGroup *parent_group)
-{
-    return new PopupTriggerCanvasItem (this, parent_group);
-}
-
 int PopupTrigger::get_auto_width () const
 {
     return 16 + get_line_width (font, text);
