@@ -1,6 +1,6 @@
-//$Id: pushbutton-prop.cc,v 1.16 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-prop.cc,v 1.18 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,7 +21,6 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include "widget-prop.h"
 #include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
@@ -35,7 +34,8 @@
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
-PushButtonProperties::PushButtonProperties (PushButton *res)
+PushButtonProperties::PushButtonProperties (PushButton *res):
+    WidgetProperties (res)
 {
     using namespace SigC;
     using WidgetOps::PropChangeOpFactory;
@@ -44,7 +44,7 @@ PushButtonProperties::PushButtonProperties (PushButton *res)
     Gtk::Widget *control;
     
     /* Resource ID */
-    WidgetProperties::add_general_controls (res, *proptable);
+    add_general_controls (*proptable);
 
     /* Label */
     TextualProperties::add_controls (res, *proptable);
@@ -69,7 +69,7 @@ PushButtonProperties::PushButtonProperties (PushButton *res)
     proptable->add_separator ();
 
     /* Position */
-    WidgetProperties::add_position_controls (res, *proptable);
+    add_position_controls (*proptable);
 
     /* Size */
     AutoWidthProperties::add_controls  (res, *proptable);
