@@ -1,6 +1,6 @@
-//$Id: pushbutton.cc,v 1.24 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.27 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,6 @@
  */
 
 #include "pushbutton.h"
-#include "pushbutton-canvas.h"
 
 #include "form-editor.h"
 
@@ -25,38 +24,19 @@ using Guikachu::Widgets::PushButton;
 using namespace Guikachu::GUI::FormEditor;
 
 PushButton::PushButton (Resources::Form   *owner,
-			const std::string &id):
-    Widget (owner, id),
+			const std::string &id,
+			serial_t           serial):
+    Widget (owner, id, serial),
     ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
     
-    editor (0),
     usable (changed, true),
     group (changed)
 {
 }
 
-PushButton::~PushButton ()
-{
-    if (editor)
-	delete editor;
-}
-
-Gtk::Widget *PushButton::create_editor ()
-{
-    if (!editor)
-	editor = new PushButtonProperties (this);
-    
-    return editor->get_editor ();
-}
-
-WidgetCanvasItem* PushButton::create_canvas_item (Gnome::CanvasGroup *parent_group)
-{
-    return new PushButtonCanvasItem (this, parent_group);
-}
-
 int PushButton::get_auto_width () const
 {
     return get_line_width (font, text) + 6;
