@@ -1,6 +1,6 @@
-//$Id: selector-trigger.cc,v 1.23 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.26 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,6 @@
  */
 
 #include "selector-trigger.h"
-#include "selector-trigger-canvas.h"
 
 #include "form-editor.h"
 
@@ -25,38 +24,19 @@ using Guikachu::Widgets::SelectorTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
 SelectorTrigger::SelectorTrigger (Resources::Form   *owner,
-				  const std::string &id):
-    Widget (owner, id),
+				  const std::string &id,
+				  serial_t           serial):
+    Widget (owner, id, serial),
     ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
     
-    editor (0),
     usable (changed, true),
     anchor_right (changed, false)
 {
 }
 
-SelectorTrigger::~SelectorTrigger ()
-{
-    if (editor)
-	delete editor;
-}
-
-Gtk::Widget* SelectorTrigger::create_editor ()
-{
-    if (!editor)
-	editor = new SelectorTriggerProperties (this);
-    
-    return editor->get_editor ();
-}
-
-WidgetCanvasItem* SelectorTrigger::create_canvas_item (Gnome::CanvasGroup *parent_group)
-{
-    return new SelectorTriggerCanvasItem (this, parent_group);
-}
-
 int SelectorTrigger::get_auto_width () const
 {
     int text_width = get_line_width (font, text);
