@@ -1,6 +1,6 @@
-//$Id: selector-trigger.h,v 1.17 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.20 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,20 +19,10 @@
 #ifndef GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_H
 #define GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_H
 
-namespace Guikachu
-{
-    namespace Widgets
-    {
-	class SelectorTrigger;
-    }
-}
-
 #include "widget.h"
 #include "auto-resizeable.h"
 #include "textual.h"
 
-#include "selector-trigger-prop.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -42,20 +32,14 @@ namespace Guikachu
 			       public AutoHeight,
 			       public Textual
 	{
-	    GUI::FormEditor::SelectorTriggerProperties *editor;
-	    
 	public:
-	    SelectorTrigger (Resources::Form *owner, const std::string &id);
-	    ~SelectorTrigger ();
+	    SelectorTrigger (Resources::Form *owner, const std::string &id, serial_t serial);
 	    
 	    Type get_type () const { return WIDGET_SELECTOR_TRIGGER; };
 	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    Gtk::Widget                       *create_editor ();
-	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
-
-	    Property<bool>   usable;
-	    Property<bool>   anchor_right;
+	    Property<bool> usable;
+	    Property<bool> anchor_right;
 
 	protected:
 	    int get_auto_width  () const;
