@@ -1,6 +1,6 @@
-//$Id: widget-canvas.cc,v 1.10 2003/01/26 17:35:52 cactus Exp $ -*- c++ -*-
+//$Id: widget-canvas.cc,v 1.12 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -44,7 +44,7 @@ WidgetCanvasItem::WidgetCanvasItem (Widget             *widget_,
     // Chain signal callbacks
     canvas_item_changed.connect (SigC::slot (this, &WidgetCanvasItem::canvas_item_changed_cb));
 
-    widget->changed.connect  (SigC::slot (this, &WidgetCanvasItem::update));
+    widget->changed.connect  (SigC::slot (this, &WidgetCanvasItem::update_hook));
     widget->selected.connect (SigC::slot (this, &WidgetCanvasItem::widget_selected_cb));
 }
 
@@ -54,6 +54,11 @@ WidgetCanvasItem::~WidgetCanvasItem ()
 	delete selection_box;
 }
 
+void WidgetCanvasItem::update_hook ()
+{
+    update ();
+}
+
 void WidgetCanvasItem::canvas_item_changed_cb ()
 {
     item->event.connect (SigC::retbind (
