@@ -1,6 +1,6 @@
-//$Id: widget.h,v 1.37 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.40 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -46,11 +46,9 @@ namespace Guikachu
 
 #include <string>
 #include <map>
-#include <iostream>
 #include <sigc++/basic_signal.h>
 
 #include "form-res.h"
-#include "form-editor/widget-canvas.h"
 #include "form-editor/form-element.h"
 #include "form-editor/widget-visitor.h"
 
@@ -62,15 +60,12 @@ namespace Guikachu
 		  public SigC::Object
     {
     protected:
-	typedef std::map<Gnome::CanvasGroup *,
-	    GUI::FormEditor::WidgetCanvasItem*> canvas_item_map_t;
+	Resources::Form *form;
+	serial_t         serial;
 	
-	Resources::Form           *owner;
-	mutable Gtk::Widget       *editor;
-	mutable canvas_item_map_t  canvas_items;
-	
-	Widget (Resources::Form   *owner,
-		const std::string &id);
+	Widget (Resources::Form   *form,
+		const std::string &id,
+		serial_t           serial);
 	
     public:
 	virtual ~Widget ();
@@ -81,12 +76,15 @@ namespace Guikachu
 	virtual void apply_visitor (WidgetVisitor &visitor) = 0;
 	
 	// Notification
-	QueuedSignal changed;
+	QueuedSignal        changed;
+	SigC::Signal0<void> deleted; 
 	
 	// Common properties
 	ID            id;
 	Property<int> x;
 	Property<int> y;
+	
+	serial_t get_serial () const { return serial; };
 
 	// FormElement implementations
 	int get_x () const { return x; };
@@ -94,13 +92,6 @@ namespace Guikachu
 	void set_x (int x_) { x = x_; };
 	void set_y (int y_) { y = y_; };
 	
-	// Preview-related methods
-	GUI::FormEditor::WidgetCanvasItem *get_canvas_item (Gnome::CanvasGroup *parent_group);
-	Gtk::Widget                       *get_editor      ();
-	
-	virtual Gtk::Widget                       *create_editor      () = 0;
-	virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group) = 0;
-	
 	Resources::Form *get_form    () const;
 	ResourceManager *get_manager () const;
     };
