@@ -1,6 +1,6 @@
-//$Id: form-res.cc,v 1.36 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.40 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -37,13 +37,15 @@
 #include "form-editor/table.h"
 #include "form-editor/gadget.h"
 
+#include <iostream>
+
 using namespace Guikachu::Resources;
 using namespace Guikachu;
 
 Form::Form (ResourceManager   *manager,
-	    const std::string &id):
-    Resource (manager, id),
-    gui (0),
+	    const std::string &id,
+	    serial_t           serial):
+    Resource (manager, id, serial),
     title (changed, id),
     help_id (changed, manager),
     menu_id (changed, manager),
@@ -60,30 +62,38 @@ Form::Form (ResourceManager   *manager,
 
 Form::~Form ()
 {
-    for (std::set<Widget*>::iterator i = widgets.begin ();
-	 i != widgets.end (); i++)
+    for (widget_map_t::iterator i = widgets.begin (); i != widgets.end (); i++)
     {
-	manager->unregister_id ((*i)->id);
-	delete (*i);
+	manager->unregister_id (i->second->id);
+	delete i->second;
 	widgets.erase (i);
     }
-    
-    delete gui;
 }
 
-void Form::show_ui ()
+namespace
 {
-    if (!gui)
-	gui = new GUI::FormWindow (this);
-
-    gui->show ();
+    bool compare_serial (const Form::widget_map_t::value_type &a,
+			 const Form::widget_map_t::value_type &b)
+    {
+	return a.first < b.first;
+    }
 }
 
 Widget* Form::create_widget (Widgets::Type type,
 			     std::string   id,
-			     bool          try_alternate_names)
+			     bool          try_alternate_names,
+			     serial_t      serial)
 {
     id = manager->validate_id (id);
+
+    if (serial < 0)
+	if (widgets.size ())
+	    serial = std::max_element (widgets.begin (), widgets.end (), compare_serial)->first + 1;
+	else
+	    serial = 0;
+
+    if (serial < 0)
+	return 0;
     
     if (id == "")
 	id = manager->create_id (Widgets::prefix_from_type (type));
@@ -104,40 +114,40 @@ Widget* Form::create_widget (Widgets::Type type,
     switch (type)
     {
     case Widgets::WIDGET_LABEL:
-	widget = new Widgets::Label (this, id);
+	widget = new Widgets::Label (this, id, serial);
 	break;
     case Widgets::WIDGET_BUTTON:
-	widget = new Widgets::Button (this, id);
+	widget = new Widgets::Button (this, id, serial);
 	break;
     case Widgets::WIDGET_PUSHBUTTON:
-	widget = new Widgets::PushButton (this, id);
+	widget = new Widgets::PushButton (this, id, serial);
 	break;
     case Widgets::WIDGET_GRAFFITI:
-	widget = new Widgets::Graffiti (this, id);
+	widget = new Widgets::Graffiti (this, id, serial);
 	break;
     case Widgets::WIDGET_SELECTOR_TRIGGER:
-	widget = new Widgets::SelectorTrigger (this, id);
+	widget = new Widgets::SelectorTrigger (this, id, serial);
 	break;
     case Widgets::WIDGET_CHECKBOX:
-	widget = new Widgets::Checkbox (this, id);
+	widget = new Widgets::Checkbox (this, id, serial);
 	break;
     case Widgets::WIDGET_LIST:
-	widget = new Widgets::List (this, id);
+	widget = new Widgets::List (this, id, serial);
 	break;
     case Widgets::WIDGET_POPUP_TRIGGER:
-	widget = new Widgets::PopupTrigger (this, id);
+	widget = new Widgets::PopupTrigger (this, id, serial);
 	break;
     case Widgets::WIDGET_SCROLLBAR:
-	widget = new Widgets::ScrollBar (this, id);
+	widget = new Widgets::ScrollBar (this, id, serial);
 	break;
     case Widgets::WIDGET_TEXT_FIELD:
-	widget = new Widgets::TextField (this, id);
+	widget = new Widgets::TextField (this, id, serial);
 	break;
     case Widgets::WIDGET_TABLE:
-	widget = new Widgets::Table (this, id);
+	widget = new Widgets::Table (this, id, serial);
 	break;
     case Widgets::WIDGET_GADGET:
-	widget = new Widgets::Gadget (this, id);
+	widget = new Widgets::Gadget (this, id, serial);
 	break;
     case Widgets::WIDGET_NONE:
     default:
@@ -145,8 +155,8 @@ Widget* Form::create_widget (Widgets::Type type,
 	return 0;
 	break;
     }
-    
-    widgets.insert (widget);
+
+    widgets[serial] = widget;
     widget->changed.connect (widget_changed.slot());
     
     widget_created (widget);
@@ -160,7 +170,7 @@ void Form::remove_widget (Widget *widget)
 {
     widget_removed.emit (widget);
 
-    widgets.erase (widget);
+    widgets.erase (widget->get_serial ());
     manager->unregister_id (widget->id);
     
     delete widget;
@@ -168,18 +178,53 @@ void Form::remove_widget (Widget *widget)
     changed ();
 }
 
-Widget* Form::get_widget (const std::string& id) const
+std::set<Widget*> Form::get_widgets () const
 {
-    std::set<Widget*>::const_iterator found;
+    std::set<Widget*> ret;
 
-    found = widgets.begin ();
-    while (found != widgets.end () && (*found)->id != id)
-	found++;
+    for (widget_map_t::const_iterator i = widgets.begin (); i != widgets.end (); i++)
+    {
+	ret.insert (i->second);
+    }
+
+    return ret;
+}
+
+namespace {
+    struct widget_finder
+    {
+	std::string search_id;
+
+	bool operator () (const Form::widget_map_t::value_type &i) const
+	    {
+		return NoCase ().compare (i.second->id, search_id) == 0;
+	    }
+
+	widget_finder (const std::string &search_id_):
+	    search_id (search_id_)
+	    {}
+    };
+}
+
+Widget* Form::get_widget (const std::string &id) const
+{
+    widget_map_t::const_iterator found =
+	std::find_if (widgets.begin (), widgets.end (), widget_finder (id));
 
     if (found == widgets.end ())
 	return 0;
     else
-	return (*found);
+	return found->second;
+}
+
+Widget* Form::get_widget (serial_t serial) const
+{
+    widget_map_t::const_iterator found = widgets.find (serial);
+
+    if (found == widgets.end ())
+	return 0;
+    else
+	return found->second;
 }
 
 int Form::get_screen_width () const
