@@ -1,6 +1,6 @@
-//$Id: form-win-layout.cc,v 1.2 2003/01/22 21:51:22 cactus Exp $ -*- c++ -*-
+//$Id: form-win-layout.cc,v 1.4 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,9 +31,9 @@ namespace
 {   
     struct WidgetPosition
     {
-	std::string widget_id;
-	int         old_x, old_y;
-	int         new_x, new_y;
+	serial_t widget_serial;
+	int      old_x, old_y;
+	int      new_x, new_y;
 
 	WidgetPosition (Widget *widget,
 			int     new_x,
@@ -53,7 +53,7 @@ namespace
     class AlignWidgetsOp: public UndoOp
     {
 	ResourceManager    *manager;
-	std::string         form_id;
+	serial_t            form_serial;
 	widget_positions_t  positions;
 
 	std::string         op_label;
@@ -74,7 +74,7 @@ namespace
 WidgetPosition::WidgetPosition (Widget *widget,
 				int     new_x_,
 				int     new_y_) :
-    widget_id (widget->id),
+    widget_serial (widget->get_serial ()),
     old_x (widget->x),
     old_y (widget->y),
     new_x (new_x_),
@@ -88,9 +88,10 @@ AlignWidgetsOp::AlignWidgetsOp (const std::set<Widget*> &widgets,
 				AlignType                align_type,
 				int                      align_target) :
     manager ((*widgets.begin ())->get_manager ()),
-    form_id ((*widgets.begin ())->get_form ()->id)
+    form_serial ((*widgets.begin ())->get_form ()->get_serial ())
 {
-    char *str = g_strdup_printf (_("Align widgets of %s"), form_id.c_str ());
+    char *str = g_strdup_printf (_("Align widgets of %s"),
+				 (*widgets.begin ())->get_form ()->id ().c_str ());
     op_label = str;
     g_free (str);
 
@@ -125,11 +126,11 @@ AlignWidgetsOp::AlignWidgetsOp (const std::set<Widget*> &widgets,
 
 void AlignWidgetsOp::undo ()
 {
-    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_id));
+    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_serial));
     for (widget_positions_t::const_iterator i = positions.begin ();
 	 i != positions.end (); ++i)
     {
-	Widget *widget = form->get_widget (i->widget_id);
+	Widget *widget = form->get_widget (i->widget_serial);
 	widget->x = i->old_x;
 	widget->y = i->old_y;
     }
@@ -137,11 +138,11 @@ void AlignWidgetsOp::undo ()
 
 void AlignWidgetsOp::redo ()
 {
-    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_id));
+    Resources::Form *form = static_cast<Resources::Form*> (manager->get_resource (form_serial));
     for (widget_positions_t::const_iterator i = positions.begin ();
 	 i != positions.end (); ++i)
     {
-	Widget *widget = form->get_widget (i->widget_id);
+	Widget *widget = form->get_widget (i->widget_serial);
 	widget->x = i->new_x;
 	widget->y = i->new_y;
     }    
