@@ -1,4 +1,4 @@
-//$Id: xml-loader.cc,v 1.5 2003/01/25 00:33:05 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.cc,v 1.6 2003/03/26 19:44:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,8 +36,7 @@
 #include "storage-processor.h"
 #include "storage-node-handlers.h"
 
-#include "mainwin.h" // FIXME: calling the GUI directly from an IO
-                     // handler is Not Good
+#include "ui.h"
 
 #include "resource-util.h"
 
@@ -107,7 +106,7 @@ IOResult XMLLoader::load (ResourceManager *manager, const std::string &uri)
 
 void XMLLoader::encoding_warning ()
 {
-    GUI::show_warning (
+    UI::show_warning (
 	_("Previous releases of Guikachu always stored\n"
 	  "strings in the local encoding, while PalmOS\n"
 	  "uses the Latin-1 character  set. The encoding\n"
