@@ -1,6 +1,6 @@
-//$Id: mainwin-io.cc,v 1.27 2002/11/02 17:28:56 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.29 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,6 +20,7 @@
 #include <libgnome/libgnome.h>
 
 #include "mainwin.h"
+#include "ui.h"
 
 #include "resource-manager.h"
 #include "session.h"
@@ -80,7 +81,7 @@ bool GUI::MainWin::check_save ()
     if (filename != "")
 	filename_message = g_strdup_printf (
 	    _("Save changes to document \"%s\"?"),
-	    visible_filename (filename).c_str ());
+	    UI::visible_filename (filename).c_str ());
     else
 	filename_message = g_strdup (
 	    _("Save changes to the current document?"));
@@ -269,7 +270,7 @@ void GUI::MainWin::filesel_export_cb (Gtk::FileSelection *fs)
 	    _("Error exporting to `%s':\n%s"),
 	    g_basename (filename.c_str ()), error_message);
 
-	GUI::show_error (message);
+	UI::show_error (message);
 	g_free (message);
     }
     
