@@ -1,6 +1,6 @@
-//$Id: mainwin.cc,v 1.44 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.46 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,6 +20,7 @@
 #include <libgnome/libgnome.h>
 
 #include "mainwin.h"
+#include "ui.h"
 
 #include <gtk--/statusbar.h>
 #include <gtk--/scrolledwindow.h>
@@ -101,7 +102,7 @@ GUI::MainWin::MainWin ():
     
     /* Help menu */
     Gnome::UI::Info m_help[] = {
-	Gnome::MenuItems::About (slot (&show_about))
+	Gnome::MenuItems::About (slot (&UI::show_about))
     };
 
     /* Create the menu bar structure */
@@ -190,7 +191,7 @@ void GUI::MainWin::update_recent_files ()
 	for (i = recent_files.begin (), num = 0;
 	     i != recent_files.end (); i++, num++)
 	{
-	    std::string vis_filename = escape_underscores (visible_filename (*i));
+	    std::string vis_filename = escape_underscores (UI::visible_filename (*i));
 	    char *menu_label;
 	    
 	    if (num < 9)
@@ -199,8 +200,7 @@ void GUI::MainWin::update_recent_files ()
 		menu_label = g_strdup_printf ("%d %s", num + 1, vis_filename.c_str ());
 	    
 	    recent_items.push_back (
-		Gnome::UI::Item (menu_label,
-				 SigC::bind ( SigC::slot (this, &MainWin::open), *i)));
+		Gnome::UI::Item (menu_label, SigC::bind (SigC::slot (this, &MainWin::open), *i)));
 	    
 	    g_free (menu_label);
 	}
@@ -276,7 +276,7 @@ void GUI::MainWin::update_title ()
 
     if (filename != "")
 	title_buf = g_strdup_printf (_("Guikachu: %s%c"),
-				     visible_filename (filename).c_str (),
+				     UI::visible_filename (filename).c_str (),
 				     manager->is_dirty () ? '*' : '\0');
     else
 	title_buf = g_strdup_printf (_("Guikachu: %s%c"), _("<unnamed>"),
@@ -287,64 +287,6 @@ void GUI::MainWin::update_title ()
     g_free (title_buf);
 }
 
-std::string GUI::visible_filename (const std::string &filename)
-{
-    // Cut off path
-    std::string retval = g_basename (filename.c_str ());
-
-    // If extension is .guikachu, cut that off as well
-    static const char         *pattern = ".guikachu";
-    static const unsigned int  pattern_len = strlen (pattern);
-    
-    if (retval.length () > pattern_len)
-    {
-	if (retval.substr (retval.length () - pattern_len) == pattern)
-	    retval.erase (retval.length () - pattern_len);
-    }
-
-    return retval;
-}
-
-void GUI::show_about ()
-{
-    std::list<std::string> authors;
-    authors.push_back ("Gerg rdi");
-    authors.push_back ("Jay Bloodworth");
-    authors.push_back ("Christopher Keith Fairbairn");
-    
-    Gnome::About *about = new Gnome::About ("Guikachu", VERSION,
-					    "(C) 2001-2002 Gerg rdi",
-					    authors,
-					    _("PalmOS resource file editor"));
-    about->run ();  
-}
-
-void GUI::show_error (const std::string &full_message,
-		      const std::string &short_message)
-{
-    if (Guikachu::Main::initialized ())
-    {
-	Gnome::Dialog *dialog = Gnome::Dialogs::error (full_message);
-	dialog->run ();
-    } else {
-	if (short_message != "")
-	    std::cerr << _("Guikachu: Error: ") << short_message << std::endl;
-    }
-}
-
-void GUI::show_warning (const std::string &full_message,
-			const std::string &short_message)
-{
-    if (Guikachu::Main::initialized ())
-    {
-	Gnome::Dialog *dialog = Gnome::Dialogs::warning (full_message);
-	dialog->run ();
-    } else {
-	if (short_message != "")
-	    std::cerr << _("Guikachu: Warning: ") << short_message << std::endl;
-    }
-}
-
 namespace {
 
 std::string escape_underscores (const std::string &text)
