@@ -1,6 +1,6 @@
-//$Id: mainwin.h,v 1.20 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.h,v 1.22 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,14 +19,6 @@
 #ifndef GUIKACHU_MAINWIN_H
 #define GUIKACHU_MAINWIN_H
 
-namespace Guikachu
-{
-    namespace GUI
-    {
-	class MainWin;
-    }
-}
-
 #include <gnome--/app.h>
 #include <gtk--/tree.h>
 #include <gtk--/fileselection.h>
@@ -91,14 +83,6 @@ namespace Guikachu
 
 	    bool check_save ();
 	};
-
-	std::string visible_filename (const std::string &filename);
-	
-	void show_about ();
-	void show_error   (const std::string &full_message,
-			   const std::string &short_message = "");
-	void show_warning (const std::string &full_message,
-			   const std::string &short_message = "");
     }
 }
 
