@@ -1,6 +1,6 @@
-//$Id: menu-res.cc,v 1.24 2003/01/29 20:29:58 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.27 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,6 @@
  */
 
 #include "menu-res.h"
-#include "menu-win.h"
 
 using namespace Guikachu;
 using namespace Guikachu::Resources;
@@ -28,23 +27,15 @@ Menu::Submenu::Submenu (const std::string &label_) :
 }
 
 Menu::Menu (ResourceManager   *manager,
-	    const std::string &id):
-    Resource (manager, id),
-    gui (0)
+	    const std::string &id,
+	    serial_t           serial):
+    Resource (manager, id, serial)
 {
 }
 
 Menu::~Menu ()
 {
-    delete gui;
-}
-
-void Menu::show_ui ()
-{
-    if (!gui)
-	gui = new GUI::MenuWindow (this);
-
-    gui->show ();
+    deregister_menu ();
 }
 
 void Menu::register_menu (const MenuTree &new_submenus)
