@@ -1,6 +1,6 @@
-//$Id: resource-manager.cc,v 1.45 2003/01/31 20:58:41 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.49 2003/06/30 14:07:56 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,9 +19,9 @@
 #include "resource-manager.h"
 
 #include "config.h"
+#include <libgnome/libgnome.h>
 
-#include "mainwin.h"
-#include "session.h"
+#include "ui.h"
 #include "resource-util.h"
 
 #include "dialog-res.h"
@@ -31,7 +31,6 @@
 #include "stringlist-res.h"
 #include "blob-res.h"
 
-#include <gtk--/main.h>
 #include <fstream>
 
 using namespace Guikachu;
@@ -142,11 +141,30 @@ std::string ResourceManager::validate_id (std::string id)
     return id;
 }
 
+namespace
+{
+    bool compare_serial (const ResourceManager::resource_map_t::value_type &a,
+			 const ResourceManager::resource_map_t::value_type &b)
+    {
+	return a.first < b.first;
+    }
+}
+
 Resource* ResourceManager::create_resource (Resources::Type type,
 					    std::string     id,
-					    bool            try_alternate_names)
+					    bool            try_alternate_names,
+					    serial_t        serial)
 {
     g_return_val_if_fail (type != Resources::RESOURCE_NONE, 0);
+
+    if (serial < 0)
+	if (resource_map.size ())
+	    serial = std::max_element (resource_map.begin (), resource_map.end (), compare_serial)->first + 1;
+	else
+	    serial = 0;
+
+    if (serial < 0)
+	return 0;
     
     id = validate_id (id);
     
@@ -170,22 +188,22 @@ Resource* ResourceManager::create_resource (Resources::Type type,
     switch (type)
     {
     case Resources::RESOURCE_DIALOG:
-	res = new Resources::Dialog (this, id);
+	res = new Resources::Dialog (this, id, serial);
 	break;
     case Resources::RESOURCE_STRING:
-	res = new Resources::String (this, id);
+	res = new Resources::String (this, id, serial);
 	break;
     case Resources::RESOURCE_STRINGLIST:
-	res = new Resources::StringList (this, id);
+	res = new Resources::StringList (this, id, serial);
 	break;
     case Resources::RESOURCE_BLOB:
-	res = new Resources::Blob (this, id);
+	res = new Resources::Blob (this, id, serial);
 	break;
     case Resources::RESOURCE_MENU:
-	res = new Resources::Menu (this, id);
+	res = new Resources::Menu (this, id, serial);
 	break;
     case Resources::RESOURCE_FORM:
-	form = new Resources::Form (this, id);
+	form = new Resources::Form (this, id, serial);
 	form->widget_changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 	res = form;
 	break;
@@ -193,7 +211,7 @@ Resource* ResourceManager::create_resource (Resources::Type type,
 	g_assert_not_reached ();
     }
     
-    resource_map.insert (std::make_pair (id, res));
+    resource_map.insert (std::make_pair (serial, res));
 
     res->changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 
@@ -226,7 +244,7 @@ bool ResourceManager::rename_resource (const std::string &old_id,
     if (id_set.find (new_id) != id_set.end ())
     {
 	char *error_msg = g_strdup_printf (_("Non-unique identifier `%s'"), new_id.c_str ());
-	GUI::show_error (error_msg);
+	UI::show_error (error_msg);
 	g_free (error_msg);
 
 	return false;
@@ -235,6 +253,7 @@ bool ResourceManager::rename_resource (const std::string &old_id,
     id_set.erase (old_id);
     id_set.insert (new_id);
 
+#if 0
     resource_map_t::iterator old_entry = resource_map.find (old_id);
     
     if (old_entry != resource_map.end ())
@@ -243,6 +262,7 @@ bool ResourceManager::rename_resource (const std::string &old_id,
 	resource_map.erase (old_entry);
 	resource_map.insert (std::make_pair (new_id, res));
     }
+#endif
 
     return true;
 }
@@ -252,7 +272,7 @@ void ResourceManager::remove_resource (Resource* resource)
     resource_removed.emit (resource);
 
     unregister_id (resource->id);
-    resource_map.erase (resource->id ());
+    resource_map.erase (resource->get_serial ());
     
     delete resource;
 
@@ -272,9 +292,36 @@ std::set<Resource*> ResourceManager::get_resources () const
     return ret;
 }
 
+namespace {
+    struct resource_finder
+    {
+	std::string search_id;
+
+	bool operator () (const ResourceManager::resource_map_t::value_type &i) const
+	    {
+		return NoCase ().compare (i.second->id, search_id) == 0;
+	    }
+
+	resource_finder (const std::string &search_id_):
+	    search_id (search_id_)
+	    {}
+    };
+}
+
 Resource* ResourceManager::get_resource (const std::string &id) const
 {
-    resource_map_t::const_iterator found = resource_map.find (id);
+    resource_map_t::const_iterator found =
+	std::find_if (resource_map.begin (), resource_map.end (), resource_finder (id));
+
+    if (found == resource_map.end ())
+	return 0;
+    else
+	return found->second;
+}
+
+Resource* ResourceManager::get_resource (serial_t serial) const
+{
+    resource_map_t::const_iterator found = resource_map.find (serial);
 
     if (found == resource_map.end ())
 	return 0;
@@ -293,9 +340,7 @@ void ResourceManager::set_dirty ()
 
 void ResourceManager::clear_dirty ()
 {
-    if (Guikachu::Main::initialized ())
-	while (Gtk::Main::events_pending ())
-	    Gtk::Main::iteration ();
+    UI::flush_events ();
     
     modification_time = 0;
     dirty = false;
