@@ -1,6 +1,6 @@
-//$Id: resource-manager.h,v 1.27 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.29 2003/06/30 14:07:56 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -49,9 +49,12 @@ namespace Guikachu
     
     class ResourceManager: public SigC::Object
     {
-	typedef std::map<std::string, Resource*, NoCase> resource_map_t;
+    public:
+//	typedef std::map<std::string, Resource*, NoCase> resource_map_t;
+	typedef std::map<serial_t, Resource*> resource_map_t;
 	typedef std::set<std::string, NoCase> id_set_t;
-	
+
+    private:
 	resource_map_t         resource_map;
 	id_set_t               id_set;
 	Resources::Application app;
@@ -68,7 +71,8 @@ namespace Guikachu
 	
 	Resource* create_resource (Resources::Type type,
 				   std::string     id = "",
-				   bool            try_alternate_names = false);
+				   bool            try_alternate_names = false,
+				   serial_t        serial = -1);
 	void remove_resource (Resource *resource);
 	bool rename_resource (const std::string &old_id,
 			      const std::string &new_id);
@@ -81,6 +85,7 @@ namespace Guikachu
 
 	std::set<Resource*>     get_resources   () const;
 	Resource*               get_resource    (const std::string &id) const;
+	Resource*               get_resource    (serial_t serial) const;
 	Resources::Application* get_application () { return &app; };
 	Target*                 get_target      () { return &target; };
 
@@ -89,7 +94,7 @@ namespace Guikachu
 	// Signals
 	SigC::Signal1<void, Resource*> resource_created;
 	SigC::Signal1<void, Resource*> resource_removed;
-       SigC::Signal0<void> dirty_state_changed;
+	SigC::Signal0<void> dirty_state_changed;
 	
 	bool   is_dirty ();
 	time_t get_modification_time ();
