@@ -1,6 +1,6 @@
-//$Id: resource.h,v 1.29 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.32 2003/06/30 14:07:56 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -38,6 +38,8 @@ namespace Guikachu
     }
     
     class Resource;
+
+    typedef int serial_t;
 }
 
 #include "queued-signal.h"
@@ -51,12 +53,14 @@ namespace Guikachu
     {
     protected:
 	Resource (ResourceManager   *manager,
-		  const std::string &id);
+		  const std::string &id,
+		  serial_t           serial);
 
 	ResourceManager *manager;
+	serial_t         serial;
 	
     public:
-	virtual ~Resource () {};
+	virtual ~Resource ();
 
 	ResourceManager * get_manager () { return manager; };
 	
@@ -67,14 +71,12 @@ namespace Guikachu
 	virtual void apply_visitor (ResourceVisitor &visitor) = 0;
 	
 	// Notification
-	QueuedSignal changed;
+	SigC::Signal0<void> deleted;
+	QueuedSignal        changed;
 	
 	// Common properties
 	ID id;
-	
-	// User interface hook
-	virtual void show_ui () = 0;
-
+	serial_t get_serial () const { return serial; };
     };
 }
 
